module.exports = {
  env: {
    es6: true,
    node: true,
    browser: true
  },
  extends: [
    "plugin:yml/standard",
    "plugin:import/recommended",
    "plugin:markdown/recommended",
    "plugin:eslint-comments/recommended",
    "plugin:jsonc/recommended-with-jsonc"
  ],
  ignorePatterns: [
    "*.min.*",
    "*.d.ts",
    "CHANGELOG.md",
    "dist",
    "LICENSE*",
    "output",
    "out",
    "coverage",
    "public",
    "temp",
    "package-lock.json",
    "pnpm-lock.yaml",
    "yarn.lock",
    "__snapshots__",
    // ignore for in lint-staged
    "*.css",
    "*.png",
    "*.ico",
    "*.toml",
    "*.patch",
    "*.txt",
    "*.crt",
    "*.key",
    "Dockerfile",
    // force include
    "!.github",
    "!.vitepress",
    "!.vscode"
  ],
  plugins: ["html", "unicorn", "no-only-tests", "unused-imports"],
  settings: {
    "import/resolver": {
      node: { extensions: [".js", ".mjs"] }
    }
  },
  overrides: [
    {
      files: ["*.json", "*.json5"],
      parser: "jsonc-eslint-parser",
      rules: {}
    },
    {
      files: ["*.yaml", "*.yml"],
      parser: "yaml-eslint-parser",
      rules: {
        "spaced-comment": "off"
      }
    },
    {
      files: ["package.json"],
      parser: "jsonc-eslint-parser",
      rules: {}
    },
    {
      files: ["*.d.ts"],
      rules: {
        "import/no-duplicates": "off"
      }
    },
    {
      files: ["*.js", "*.cjs"],
      rules: {
        "@typescript-eslint/no-var-requires": "off"
      }
    },
    {
      files: ["*.ts", "*.tsx", "*.mts", "*.cts"],
      rules: {}
    },
    {
      files: ["scripts/**/*.*", "cli.*"],
      rules: {
        "no-console": "off"
      }
    },
    {
      files: ["*.test.ts", "*.test.js", "*.spec.ts", "*.spec.js"],
      rules: {
        "no-unused-expressions": "off"
      }
    },
    {
      files: ["**/*.md/*.*"],
      rules: {
        "no-undef": "off",
        "no-alert": "off",
        "no-console": "off",
        "no-unused-vars": "off",
        "import/no-unresolved": "off",
        "no-restricted-imports": "off",
        "no-unused-expressions": "off",
        "unused-imports/no-unused-vars": "off",
        "unused-imports/no-unused-imports": "off",
        "@typescript-eslint/comma-dangle": "off",
        "@typescript-eslint/no-redeclare": "off",
        "@typescript-eslint/no-unused-vars": "off",
        "@typescript-eslint/no-var-requires": "off",
        "@typescript-eslint/no-use-before-define": "off",
        "@typescript-eslint/consistent-type-imports": "off"
      }
    }
  ],
  rules: {
    // import
    "import/no-unresolved": "off",
    "import/no-absolute-path": "off",

    // Common
    "unused-imports/no-unused-vars": [
      "warn",
      {
        vars: "all",
        varsIgnorePattern: "^_",
        args: "after-used",
        argsIgnorePattern: "^_"
      }
    ],

    camelcase: "off",
    "no-return-await": "off",
    "no-param-reassign": "off",
    "no-constant-condition": "warn",
    "func-call-spacing": ["off", "never"],

    // es6
    "generator-star-spacing": "off",

    // best-practice
    "consistent-return": "off",
    complexity: ["off", 11],
    "no-alert": "warn",
    "no-useless-escape": "off",
    "require-await": "off",
    "no-return-assign": "off",
    eqeqeq: "off",
    "prefer-const": "off",
    "no-fallthrough": "off",
    "object-shorthand": "off",
    "no-unsafe-finally": "off",
    "no-mixed-operators": "off",
    "no-unused-expressions": "off",
    "array-callback-return": "off",
    "no-useless-computed-key": "off",
    "no-async-promise-executor": "off",
    "prefer-promise-reject-errors": "off",
    "eslint-comments/disable-enable-pair": "off",
    "import/no-named-as-default-member": "off",
    "import/no-named-as-default": "off",
    "import/namespace": "off",
    "n/no-callback-literal": "off",

    // yml
    "yml/no-empty-document": "off"
  }
};
